@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App 6.003; # TRIAL
+package Dist::Zilla::App;
 # ABSTRACT: Dist::Zilla's App::Cmd
-
+$Dist::Zilla::App::VERSION = '6.004'; # TRIAL
 use App::Cmd::Setup 0.330 -app; # better compilation error detection
 
 use Carp ();
@@ -173,7 +173,7 @@ Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 METHODS
 
