@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command 6.003; # TRIAL
+package Dist::Zilla::App::Command;
 # ABSTRACT: base class for dzil commands
-
+$Dist::Zilla::App::Command::VERSION = '6.004'; # TRIAL
 use App::Cmd::Setup -command;
 
 #pod =method zilla
@@ -42,7 +42,7 @@ Dist::Zilla::App::Command - base class for dzil commands
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 METHODS
 
