@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::clean 6.003; # TRIAL
+package Dist::Zilla::App::Command::clean;
 # ABSTRACT: clean up after build, test, or install
-
+$Dist::Zilla::App::Command::clean::VERSION = '6.004'; # TRIAL
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -50,7 +50,7 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
