@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::listdeps 6.003; # TRIAL
+package Dist::Zilla::App::Command::listdeps;
 # ABSTRACT: print your distribution's prerequisites
-
+$Dist::Zilla::App::Command::listdeps::VERSION = '6.004'; # TRIAL
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -177,7 +177,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
