@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::nop 6.003; # TRIAL
+package Dist::Zilla::App::Command::nop;
 # ABSTRACT: initialize dzil, then exit
-
+$Dist::Zilla::App::Command::nop::VERSION = '6.004'; # TRIAL
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -44,7 +44,7 @@ Dist::Zilla::App::Command::nop - initialize dzil, then exit
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
