@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::setup 6.003; # TRIAL
+package Dist::Zilla::App::Command::setup;
 # ABSTRACT: set up a basic global config file
-
+$Dist::Zilla::App::Command::setup::VERSION = '6.004'; # TRIAL
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -168,7 +168,7 @@ Dist::Zilla::App::Command::setup - set up a basic global config file
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
