@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::smoke 6.003; # TRIAL
+package Dist::Zilla::App::Command::smoke;
 # ABSTRACT: smoke your dist
-
+$Dist::Zilla::App::Command::smoke::VERSION = '6.004'; # TRIAL
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -78,7 +78,7 @@ Dist::Zilla::App::Command::smoke - smoke your dist
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
