@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Tester 6.003; # TRIAL
+package Dist::Zilla::App::Tester;
 # ABSTRACT: testing library for Dist::Zilla::App
-
+$Dist::Zilla::App::Tester::VERSION = '6.004'; # TRIAL
 use parent 'App::Cmd::Tester::CaptureExternal';
 use App::Cmd::Tester 0.306 (); # result_class, ->app
 
@@ -43,9 +43,9 @@ sub test_dzil {
 }
 
 {
-  package Dist::Zilla::App::Tester::Result 6.003; # TRIAL
-
-  BEGIN { our @ISA = qw(App::Cmd::Tester::Result); }
+  package Dist::Zilla::App::Tester::Result;
+$Dist::Zilla::App::Tester::Result::VERSION = '6.004'; # TRIAL
+BEGIN { our @ISA = qw(App::Cmd::Tester::Result); }
 
   sub tempdir {
     my ($self) = @_;
@@ -93,7 +93,7 @@ Dist::Zilla::App::Tester - testing library for Dist::Zilla::App
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
