@@ -1,6 +1,6 @@
-package Dist::Zilla::Chrome::Term 6.003; # TRIAL
+package Dist::Zilla::Chrome::Term;
 # ABSTRACT: chrome used for terminal-based interaction
-
+$Dist::Zilla::Chrome::Term::VERSION = '6.004'; # TRIAL
 use Moose;
 
 #pod =head1 OVERVIEW
@@ -153,7 +153,7 @@ Dist::Zilla::Chrome::Term - chrome used for terminal-based interaction
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 OVERVIEW
 
