@@ -1,6 +1,6 @@
-package Dist::Zilla::Chrome::Test 6.003; # TRIAL
+package Dist::Zilla::Chrome::Test;
 # ABSTRACT: the chrome used by Dist::Zilla::Tester
-
+$Dist::Zilla::Chrome::Test::VERSION = '6.004'; # TRIAL
 use Moose;
 
 use MooseX::Types::Moose qw(ArrayRef HashRef Str);
@@ -87,7 +87,7 @@ Dist::Zilla::Chrome::Test - the chrome used by Dist::Zilla::Tester
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 ATTRIBUTES
 
