@@ -1,6 +1,6 @@
-package Dist::Zilla::Dist::Builder 6.003; # TRIAL
+package Dist::Zilla::Dist::Builder;
 # ABSTRACT: dist zilla subclass for building dists
-
+$Dist::Zilla::Dist::Builder::VERSION = '6.004'; # TRIAL
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
@@ -874,7 +874,7 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 ATTRIBUTES
 
