@@ -1,6 +1,6 @@
-package Dist::Zilla::Dist::Minter 6.003; # TRIAL
+package Dist::Zilla::Dist::Minter;
 # ABSTRACT: distribution builder; installer not included!
-
+$Dist::Zilla::Dist::Minter::VERSION = '6.004'; # TRIAL
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
@@ -151,7 +151,7 @@ Dist::Zilla::Dist::Minter - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
