@@ -1,6 +1,6 @@
-package Dist::Zilla::File::FromCode 6.003; # TRIAL
+package Dist::Zilla::File::FromCode;
 # ABSTRACT: a file whose content is (re-)built on demand
-
+$Dist::Zilla::File::FromCode::VERSION = '6.004'; # TRIAL
 use Moose;
 use Moose::Util::TypeConstraints;
 
@@ -116,7 +116,7 @@ Dist::Zilla::File::FromCode - a file whose content is (re-)built on demand
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
