@@ -1,6 +1,6 @@
-package Dist::Zilla::File::InMemory 6.003; # TRIAL
+package Dist::Zilla::File::InMemory;
 # ABSTRACT: a file that you build entirely in memory
-
+$Dist::Zilla::File::InMemory::VERSION = '6.004'; # TRIAL
 use Moose;
 
 use namespace::autoclean;
@@ -51,7 +51,7 @@ Dist::Zilla::File::InMemory - a file that you build entirely in memory
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
