@@ -1,6 +1,6 @@
-package Dist::Zilla::MVP::Assembler::GlobalConfig 6.003; # TRIAL
+package Dist::Zilla::MVP::Assembler::GlobalConfig;
 # ABSTRACT: Dist::Zilla::MVP::Assembler for global configuration
-
+$Dist::Zilla::MVP::Assembler::GlobalConfig::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 
@@ -59,7 +59,7 @@ Dist::Zilla::MVP::Assembler::GlobalConfig - Dist::Zilla::MVP::Assembler for glob
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 OVERVIEW
 
