@@ -1,6 +1,6 @@
-package Dist::Zilla::MVP::Assembler::Zilla 6.003; # TRIAL
+package Dist::Zilla::MVP::Assembler::Zilla;
 # ABSTRACT: Dist::Zilla::MVP::Assembler for the Dist::Zilla object
-
+$Dist::Zilla::MVP::Assembler::Zilla::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 
@@ -82,7 +82,7 @@ Dist::Zilla::MVP::Assembler::Zilla - Dist::Zilla::MVP::Assembler for the Dist::Z
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 OVERVIEW
 
