@@ -1,6 +1,6 @@
-package Dist::Zilla::MVP::RootSection 6.003; # TRIAL
+package Dist::Zilla::MVP::RootSection;
 # ABSTRACT: a standard section in Dist::Zilla's configuration sequence
-
+$Dist::Zilla::MVP::RootSection::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Config::MVP::Section';
 
@@ -77,7 +77,7 @@ Dist::Zilla::MVP::RootSection - a standard section in Dist::Zilla's configuratio
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
