@@ -1,6 +1,6 @@
-package Dist::Zilla::MVP::Section 6.003; # TRIAL
+package Dist::Zilla::MVP::Section;
 # ABSTRACT: a standard section in Dist::Zilla's configuration sequence
-
+$Dist::Zilla::MVP::Section::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Config::MVP::Section';
 
@@ -56,7 +56,7 @@ Dist::Zilla::MVP::Section - a standard section in Dist::Zilla's configuration se
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
