@@ -1,6 +1,6 @@
-package Dist::Zilla::MintingProfile::Default 6.003; # TRIAL
+package Dist::Zilla::MintingProfile::Default;
 # ABSTRACT: Default minting profile provider
-
+$Dist::Zilla::MintingProfile::Default::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
@@ -48,7 +48,7 @@ Dist::Zilla::MintingProfile::Default - Default minting profile provider
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
