@@ -2,9 +2,9 @@ use strict;
 use warnings;
 use utf8;
 
-package Dist::Zilla::Path 6.003; # TRIAL
+package Dist::Zilla::Path;
 # ABSTRACT: a helper to get Path::Tiny objects
-
+$Dist::Zilla::Path::VERSION = '6.004'; # TRIAL
 use parent 'Path::Tiny';
 
 use Path::Tiny 0.052 qw();  # issue 427
@@ -62,7 +62,7 @@ Dist::Zilla::Path - a helper to get Path::Tiny objects
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
