@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::CPANFile 6.003; # TRIAL
+package Dist::Zilla::Plugin::CPANFile;
 # ABSTRACT: produce a cpanfile prereqs file
-
+$Dist::Zilla::Plugin::CPANFile::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -88,7 +88,7 @@ Dist::Zilla::Plugin::CPANFile - produce a cpanfile prereqs file
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
