@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ConfirmRelease 6.003; # TRIAL
+package Dist::Zilla::Plugin::ConfirmRelease;
 # ABSTRACT: prompt for confirmation before releasing
-
+$Dist::Zilla::Plugin::ConfirmRelease::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 
@@ -53,7 +53,7 @@ Dist::Zilla::Plugin::ConfirmRelease - prompt for confirmation before releasing
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
