@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::DistINI 6.003; # TRIAL
+package Dist::Zilla::Plugin::DistINI;
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
-
+$Dist::Zilla::Plugin::DistINI::VERSION = '6.004'; # TRIAL
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer);
 
@@ -116,7 +116,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
