@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ExecDir 6.003; # TRIAL
+package Dist::Zilla::Plugin::ExecDir;
 # ABSTRACT: install a directory's contents as executables
-
+$Dist::Zilla::Plugin::ExecDir::VERSION = '6.004'; # TRIAL
 use Moose;
 
 use namespace::autoclean;
@@ -47,7 +47,7 @@ Dist::Zilla::Plugin::ExecDir - install a directory's contents as executables
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
