@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ExtraTests 6.003; # TRIAL
+package Dist::Zilla::Plugin::ExtraTests;
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
-
+$Dist::Zilla::Plugin::ExtraTests::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
@@ -82,7 +82,7 @@ Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
