@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::FakeRelease 6.003; # TRIAL
+package Dist::Zilla::Plugin::FakeRelease;
 # ABSTRACT: fake plugin to test release
-
+$Dist::Zilla::Plugin::FakeRelease::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::Releaser';
 
@@ -73,7 +73,7 @@ Dist::Zilla::Plugin::FakeRelease - fake plugin to test release
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
