@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::FileFinder::Filter 6.003; # TRIAL
+package Dist::Zilla::Plugin::FileFinder::Filter;
 # ABSTRACT: filter matches from other FileFinders
-
+$Dist::Zilla::Plugin::FileFinder::Filter::VERSION = '6.004'; # TRIAL
 use Moose;
 with(
   'Dist::Zilla::Role::FileFinder',
@@ -103,7 +103,7 @@ Dist::Zilla::Plugin::FileFinder::Filter - filter matches from other FileFinders
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
