@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::GatherDir 6.003; # TRIAL
+package Dist::Zilla::Plugin::GatherDir;
 # ABSTRACT: gather all the files in a directory
-
+$Dist::Zilla::Plugin::GatherDir::VERSION = '6.004'; # TRIAL
 use Moose;
 use Dist::Zilla::Types qw(Path);
 with 'Dist::Zilla::Role::FileGatherer';
@@ -255,7 +255,7 @@ Dist::Zilla::Plugin::GatherDir - gather all the files in a directory
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
