@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::GatherDir::Template 6.003; # TRIAL
+package Dist::Zilla::Plugin::GatherDir::Template;
 # ABSTRACT: gather all the files in a directory and use them as templates
-
+$Dist::Zilla::Plugin::GatherDir::Template::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir';
 with 'Dist::Zilla::Role::TextTemplate';
@@ -118,7 +118,7 @@ Dist::Zilla::Plugin::GatherDir::Template - gather all the files in a directory a
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
