@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MakeMaker::Runner 6.003; # TRIAL
+package Dist::Zilla::Plugin::MakeMaker::Runner;
 # ABSTRACT: Test and build dists with a Makefile.PL
-
+$Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '6.004'; # TRIAL
 use Moose;
 with(
   'Dist::Zilla::Role::BuildRunner',
@@ -73,7 +73,7 @@ Dist::Zilla::Plugin::MakeMaker::Runner - Test and build dists with a Makefile.PL
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
