@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ManifestSkip 6.003; # TRIAL
+package Dist::Zilla::Plugin::ManifestSkip;
 # ABSTRACT: decline to build files that appear in a MANIFEST.SKIP-like file
-
+$Dist::Zilla::Plugin::ManifestSkip::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::FilePruner';
 
@@ -90,7 +90,7 @@ Dist::Zilla::Plugin::ManifestSkip - decline to build files that appear in a MANI
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
