@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaConfig 6.003; # TRIAL
+package Dist::Zilla::Plugin::MetaConfig;
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
-
+$Dist::Zilla::Plugin::MetaConfig::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -74,7 +74,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
