@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaJSON 6.003; # TRIAL
+package Dist::Zilla::Plugin::MetaJSON;
 # ABSTRACT: produce a META.json
-
+$Dist::Zilla::Plugin::MetaJSON::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -114,7 +114,7 @@ Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
