@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaResources 6.003; # TRIAL
+package Dist::Zilla::Plugin::MetaResources;
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
-
+$Dist::Zilla::Plugin::MetaResources::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -93,7 +93,7 @@ Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribut
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
