@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaYAML 6.003; # TRIAL
+package Dist::Zilla::Plugin::MetaYAML;
 # ABSTRACT: produce a META.yml
-
+$Dist::Zilla::Plugin::MetaYAML::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -117,7 +117,7 @@ Dist::Zilla::Plugin::MetaYAML - produce a META.yml
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
