@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ModuleShareDirs 6.003; # TRIAL
+package Dist::Zilla::Plugin::ModuleShareDirs;
 # ABSTRACT: install a directory's contents as module-based "ShareDir" content
-
+$Dist::Zilla::Plugin::ModuleShareDirs::VERSION = '6.004'; # TRIAL
 use Moose;
 
 use namespace::autoclean;
@@ -77,7 +77,7 @@ Dist::Zilla::Plugin::ModuleShareDirs - install a directory's contents as module-
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
