@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::PkgDist 6.003; # TRIAL
+package Dist::Zilla::Plugin::PkgDist;
 # ABSTRACT: add a $DIST to your packages
-
+$Dist::Zilla::Plugin::PkgDist::VERSION = '6.004'; # TRIAL
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -119,7 +119,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
