@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::Prereqs 6.003; # TRIAL
+package Dist::Zilla::Plugin::Prereqs;
 # ABSTRACT: list simple prerequisites
-
+$Dist::Zilla::Plugin::Prereqs::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::PrereqSource';
 
@@ -216,7 +216,7 @@ Dist::Zilla::Plugin::Prereqs - list simple prerequisites
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
