@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::PruneCruft 6.003; # TRIAL
+package Dist::Zilla::Plugin::PruneCruft;
 # ABSTRACT: prune stuff that you probably don't mean to include
-
+$Dist::Zilla::Plugin::PruneCruft::VERSION = '6.004'; # TRIAL
 use Moose;
 use Moose::Util::TypeConstraints;
 with 'Dist::Zilla::Role::FilePruner';
@@ -114,7 +114,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
