@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::RemovePrereqs 6.003; # TRIAL
+package Dist::Zilla::Plugin::RemovePrereqs;
 # ABSTRACT: a plugin to remove gathered prereqs
-
+$Dist::Zilla::Plugin::RemovePrereqs::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::PrereqSource';
 
@@ -85,7 +85,7 @@ Dist::Zilla::Plugin::RemovePrereqs - a plugin to remove gathered prereqs
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
