@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ShareDir 6.003; # TRIAL
+package Dist::Zilla::Plugin::ShareDir;
 # ABSTRACT: install a directory's contents as "ShareDir" content
-
+$Dist::Zilla::Plugin::ShareDir::VERSION = '6.004'; # TRIAL
 use Moose;
 
 use namespace::autoclean;
@@ -56,7 +56,7 @@ Dist::Zilla::Plugin::ShareDir - install a directory's contents as "ShareDir" con
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
