@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::TestRelease 6.003; # TRIAL
+package Dist::Zilla::Plugin::TestRelease;
 # ABSTRACT: extract archive and run tests before releasing the dist
-
+$Dist::Zilla::Plugin::TestRelease::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 
@@ -73,7 +73,7 @@ Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasin
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
