@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::UploadToCPAN 6.003; # TRIAL
+package Dist::Zilla::Plugin::UploadToCPAN;
 # ABSTRACT: upload the dist to CPAN
-
+$Dist::Zilla::Plugin::UploadToCPAN::VERSION = '6.004'; # TRIAL
 use Moose;
 with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
 
@@ -284,7 +284,7 @@ Dist::Zilla::Plugin::UploadToCPAN - upload the dist to CPAN
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 SYNOPSIS
 
