@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::Basic 6.003; # TRIAL
+package Dist::Zilla::PluginBundle::Basic;
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
-
+$Dist::Zilla::PluginBundle::Basic::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -78,7 +78,7 @@ Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPA
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
