@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::Classic 6.003; # TRIAL
+package Dist::Zilla::PluginBundle::Classic;
 # ABSTRACT: the classic (old) default configuration for Dist::Zilla
-
+$Dist::Zilla::PluginBundle::Classic::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -83,7 +83,7 @@ Dist::Zilla::PluginBundle::Classic - the classic (old) default configuration for
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
