@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::FakeClassic 6.003; # TRIAL
+package Dist::Zilla::PluginBundle::FakeClassic;
 # ABSTRACT: build something more or less like a "classic" CPAN dist
-
+$Dist::Zilla::PluginBundle::FakeClassic::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Dist::Zilla::PluginBundle::Classic';
 
@@ -40,7 +40,7 @@ Dist::Zilla::PluginBundle::FakeClassic - build something more or less like a "cl
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
