@@ -1,6 +1,6 @@
-package Dist::Zilla::Prereqs 6.003; # TRIAL
+package Dist::Zilla::Prereqs;
 # ABSTRACT: the prerequisites of a Dist::Zilla distribution
-
+$Dist::Zilla::Prereqs::VERSION = '6.004'; # TRIAL
 use Moose;
 use MooseX::Types::Moose qw(Bool HashRef);
 
@@ -142,7 +142,7 @@ Dist::Zilla::Prereqs - the prerequisites of a Dist::Zilla distribution
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
