@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::AfterMint 6.003; # TRIAL
+package Dist::Zilla::Role::AfterMint;
 # ABSTRACT: something that runs after minting is mostly complete
-
+$Dist::Zilla::Role::AfterMint::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -32,7 +32,7 @@ Dist::Zilla::Role::AfterMint - something that runs after minting is mostly compl
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
