@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::BeforeArchive 6.003; # TRIAL
+package Dist::Zilla::Role::BeforeArchive;
 # ABSTRACT: something that runs before the archive file is built
-
+$Dist::Zilla::Role::BeforeArchive::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::BeforeArchive - something that runs before the archive file i
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
