@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::BeforeBuild 6.003; # TRIAL
+package Dist::Zilla::Role::BeforeBuild;
 # ABSTRACT: something that runs before building really begins
-
+$Dist::Zilla::Role::BeforeBuild::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::BeforeBuild - something that runs before building really begi
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
