@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::BeforeMint 6.003; # TRIAL
+package Dist::Zilla::Role::BeforeMint;
 # ABSTRACT: something that runs before minting really begins
-
+$Dist::Zilla::Role::BeforeMint::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::BeforeMint - something that runs before minting really begins
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
