@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::BeforeRelease 6.003; # TRIAL
+package Dist::Zilla::Role::BeforeRelease;
 # ABSTRACT: something that runs before release really begins
-
+$Dist::Zilla::Role::BeforeRelease::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::BeforeRelease - something that runs before release really beg
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
