@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Chrome 6.003; # TRIAL
+package Dist::Zilla::Role::Chrome;
 # ABSTRACT: something that provides a user interface for Dist::Zilla
-
+$Dist::Zilla::Role::Chrome::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use namespace::autoclean;
@@ -25,7 +25,7 @@ Dist::Zilla::Role::Chrome - something that provides a user interface for Dist::Z
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
