@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::ConfigDumper 6.003; # TRIAL
+package Dist::Zilla::Role::ConfigDumper;
 # ABSTRACT: something that can dump its (public, simplified) configuration
-
+$Dist::Zilla::Role::ConfigDumper::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use namespace::autoclean;
@@ -21,7 +21,7 @@ Dist::Zilla::Role::ConfigDumper - something that can dump its (public, simplifie
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
