@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::EncodingProvider 6.003; # TRIAL
+package Dist::Zilla::Role::EncodingProvider;
 # ABSTRACT: something that sets a files' encoding
-
+$Dist::Zilla::Role::EncodingProvider::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -31,7 +31,7 @@ Dist::Zilla::Role::EncodingProvider - something that sets a files' encoding
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
