@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::ExecFiles 6.003; # TRIAL
+package Dist::Zilla::Role::ExecFiles;
 # ABSTRACT: something that finds files to install as executables
-
+$Dist::Zilla::Role::ExecFiles::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -32,7 +32,7 @@ Dist::Zilla::Role::ExecFiles - something that finds files to install as executab
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
