@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::File 6.003; # TRIAL
+package Dist::Zilla::Role::File;
 # ABSTRACT: something that can act like a file
-
+$Dist::Zilla::Role::File::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use Dist::Zilla::Types qw(_Filename);
@@ -185,7 +185,7 @@ Dist::Zilla::Role::File - something that can act like a file
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
