@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::FileFinder 6.003; # TRIAL
+package Dist::Zilla::Role::FileFinder;
 # ABSTRACT: something that finds files within the distribution
-
+$Dist::Zilla::Role::FileFinder::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -54,7 +54,7 @@ Dist::Zilla::Role::FileFinder - something that finds files within the distributi
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
