@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::FileFinderUser 6.003; # TRIAL
+package Dist::Zilla::Role::FileFinderUser;
 # ABSTRACT: something that uses FileFinder plugins
-
+$Dist::Zilla::Role::FileFinderUser::VERSION = '6.004'; # TRIAL
 use MooseX::Role::Parameterized 1.01;
 
 use namespace::autoclean;
@@ -178,7 +178,7 @@ Dist::Zilla::Role::FileFinderUser - something that uses FileFinder plugins
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
