@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::FileInjector 6.003; # TRIAL
+package Dist::Zilla::Role::FileInjector;
 # ABSTRACT: something that can add files to the distribution
-
+$Dist::Zilla::Role::FileInjector::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use namespace::autoclean;
@@ -46,7 +46,7 @@ Dist::Zilla::Role::FileInjector - something that can add files to the distributi
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
