@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::FileMunger 6.003; # TRIAL
+package Dist::Zilla::Role::FileMunger;
 # ABSTRACT: something that alters a file's destination or content
-
+$Dist::Zilla::Role::FileMunger::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -54,7 +54,7 @@ Dist::Zilla::Role::FileMunger - something that alters a file's destination or co
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
