@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::FilePruner 6.003; # TRIAL
+package Dist::Zilla::Role::FilePruner;
 # ABSTRACT: something that removes found files from the distribution
-
+$Dist::Zilla::Role::FilePruner::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -31,7 +31,7 @@ Dist::Zilla::Role::FilePruner - something that removes found files from the dist
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
