@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::MintingProfile 6.003; # TRIAL
+package Dist::Zilla::Role::MintingProfile;
 # ABSTRACT: something that can find a minting profile dir
-
+$Dist::Zilla::Role::MintingProfile::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use namespace::autoclean;
@@ -42,7 +42,7 @@ Dist::Zilla::Role::MintingProfile - something that can find a minting profile di
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
