@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::MintingProfile::ShareDir 6.003; # TRIAL
+package Dist::Zilla::Role::MintingProfile::ShareDir;
 # ABSTRACT: something that keeps its minting profile in a sharedir
-
+$Dist::Zilla::Role::MintingProfile::ShareDir::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::MintingProfile';
 
@@ -41,7 +41,7 @@ Dist::Zilla::Role::MintingProfile::ShareDir - something that keeps its minting p
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
