@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::ModuleMaker 6.003; # TRIAL
+package Dist::Zilla::Role::ModuleMaker;
 # ABSTRACT: something that injects module files into the dist
-
+$Dist::Zilla::Role::ModuleMaker::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with qw(
   Dist::Zilla::Role::Plugin
@@ -39,7 +39,7 @@ Dist::Zilla::Role::ModuleMaker - something that injects module files into the di
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
