@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::NameProvider 6.003; # TRIAL
+package Dist::Zilla::Role::NameProvider;
 # ABSTRACT: something that provides a name for the dist
-
+$Dist::Zilla::Role::NameProvider::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -32,7 +32,7 @@ Dist::Zilla::Role::NameProvider - something that provides a name for the dist
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
