@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::PPI 6.003; # TRIAL
+package Dist::Zilla::Role::PPI;
 # ABSTRACT: a role for plugins which use PPI
-
+$Dist::Zilla::Role::PPI::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 use Digest::MD5 qw(md5);
 use namespace::autoclean;
@@ -127,7 +127,7 @@ Dist::Zilla::Role::PPI - a role for plugins which use PPI
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
