@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::PluginBundle 6.003; # TRIAL
+package Dist::Zilla::Role::PluginBundle;
 # ABSTRACT: something that bundles a bunch of plugins
-
+$Dist::Zilla::Role::PluginBundle::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use namespace::autoclean;
@@ -36,7 +36,7 @@ Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
