@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::PrereqSource 6.003; # TRIAL
+package Dist::Zilla::Role::PrereqSource;
 # ABSTRACT: something that registers prerequisites
-
+$Dist::Zilla::Role::PrereqSource::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::PrereqSource - something that registers prerequisites
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
