@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::ReleaseStatusProvider 6.003; # TRIAL
+package Dist::Zilla::Role::ReleaseStatusProvider;
 # ABSTRACT: something that provides a release status for the dist
-
+$Dist::Zilla::Role::ReleaseStatusProvider::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -38,7 +38,7 @@ Dist::Zilla::Role::ReleaseStatusProvider - something that provides a release sta
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
