@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Releaser 6.003; # TRIAL
+package Dist::Zilla::Role::Releaser;
 # ABSTRACT: something that makes a release of the dist
-
+$Dist::Zilla::Role::Releaser::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::Releaser - something that makes a release of the dist
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 DESCRIPTION
 
