@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Stash 6.003; # TRIAL
+package Dist::Zilla::Role::Stash;
 # ABSTRACT: something that stores options or data for later reference
-
+$Dist::Zilla::Role::Stash::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 use namespace::autoclean;
@@ -37,7 +37,7 @@ Dist::Zilla::Role::Stash - something that stores options or data for later refer
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
