@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Stash::Authors 6.003; # TRIAL
+package Dist::Zilla::Role::Stash::Authors;
 # ABSTRACT: a stash that provides a list of author strings
-
+$Dist::Zilla::Role::Stash::Authors::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Stash';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::Stash::Authors - a stash that provides a list of author strin
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 OVERVIEW
 
