@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::Stash::Login 6.003; # TRIAL
+package Dist::Zilla::Role::Stash::Login;
 # ABSTRACT: a stash with username/password credentials
-
+$Dist::Zilla::Role::Stash::Login::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 with 'Dist::Zilla::Role::Stash';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::Stash::Login - a stash with username/password credentials
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 OVERVIEW
 
