@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::StubBuild 6.003; # TRIAL
+package Dist::Zilla::Role::StubBuild;
 # ABSTRACT: provides an empty BUILD methods
-
+$Dist::Zilla::Role::StubBuild::VERSION = '6.004'; # TRIAL
 use Moose::Role;
 
 sub BUILD {}
@@ -19,7 +19,7 @@ Dist::Zilla::Role::StubBuild - provides an empty BUILD methods
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
