@@ -1,6 +1,6 @@
-package Dist::Zilla::Stash::PAUSE 6.003; # TRIAL
+package Dist::Zilla::Stash::PAUSE;
 # ABSTRACT: a stash of your PAUSE credentials
-
+$Dist::Zilla::Stash::PAUSE::VERSION = '6.004'; # TRIAL
 use Moose;
 
 use namespace::autoclean;
@@ -44,7 +44,7 @@ Dist::Zilla::Stash::PAUSE - a stash of your PAUSE credentials
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 OVERVIEW
 
