@@ -1,6 +1,6 @@
-package Dist::Zilla::Stash::Rights 6.003; # TRIAL
+package Dist::Zilla::Stash::Rights;
 # ABSTRACT: a stash of your default licensing terms
-
+$Dist::Zilla::Stash::Rights::VERSION = '6.004'; # TRIAL
 use Moose;
 with 'Dist::Zilla::Role::Stash';
 
@@ -38,7 +38,7 @@ Dist::Zilla::Stash::Rights - a stash of your default licensing terms
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
