@@ -1,6 +1,6 @@
-package Dist::Zilla::Tester 6.003; # TRIAL
+package Dist::Zilla::Tester;
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
-
+$Dist::Zilla::Tester::VERSION = '6.004'; # TRIAL
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 
@@ -112,9 +112,9 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Builder 6.003; # TRIAL
-
-  use Moose;
+  package Dist::Zilla::Tester::_Builder;
+$Dist::Zilla::Tester::_Builder::VERSION = '6.004'; # TRIAL
+use Moose;
   extends 'Dist::Zilla::Dist::Builder';
   with 'Dist::Zilla::Tester::_Role';
 
@@ -250,9 +250,9 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Minter 6.003; # TRIAL
-
-  use Moose;
+  package Dist::Zilla::Tester::_Minter;
+$Dist::Zilla::Tester::_Minter::VERSION = '6.004'; # TRIAL
+use Moose;
   extends 'Dist::Zilla::Dist::Minter';
   with 'Dist::Zilla::Tester::_Role';
 
@@ -355,7 +355,7 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
