@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::Util::AuthorDeps 6.003; # TRIAL
+package Dist::Zilla::Util::AuthorDeps;
 # ABSTRACT: Utils for listing your distribution's author dependencies
-
+$Dist::Zilla::Util::AuthorDeps::VERSION = '6.004'; # TRIAL
 use Dist::Zilla::Util;
 use Path::Tiny;
 use List::Util 1.45 ();
@@ -129,7 +129,7 @@ Dist::Zilla::Util::AuthorDeps - Utils for listing your distribution's author dep
 
 =head1 VERSION
 
-version 6.003
+version 6.004
 
 =head1 AUTHOR
 
